@@ -5,6 +5,7 @@ from django.db import models
 class Person(models.Model):
 
     name = models.CharField(max_length=50)
+    email = models.EmailField(null=True, blank=True)
 
     class Meta:
         app_label = 'tests'
@@ -22,7 +23,7 @@ class Book(models.Model):
 
     """ Book has no admin, its an inline in the Author admin"""
 
-    author = models.ForeignKey(Author)
+    author = models.ForeignKey(Author, null=True)
     name = models.CharField(max_length=50)
     mentions_persons = models.ManyToManyField(Person, help_text="MENTIONS PERSONS HELP TEXT")
 
